@@ -13,7 +13,7 @@ except ImportError:
 
 class AliyunOSS:
     def __init__(self, ac_id=pre_check('aliyun_oss_acid'), ac_key=pre_check('aliyun_oss_ackey'),
-                 bucket_url=pre_check('aliyun_oss_bucket_url'), df_bucket=pre_check('aliyun_oss_df_bucket')):
+                 bucket_url=pre_check('aliyun_oss_df_endpoint'), df_bucket=pre_check('aliyun_oss_df_bucket')):
         """
         初始化并登陆阿里云对象存储
 
@@ -28,6 +28,7 @@ class AliyunOSS:
         self.ac_key = ac_key
         self.bucket_url = bucket_url
         self.df_bucket = df_bucket
+        self.progress, self.trans_id, self._progress_file_name = None, None, None
         self.auth = oss2.Auth(self.ac_id, self.ac_key)
 
     def get_func_table(self):
@@ -45,6 +46,25 @@ class AliyunOSS:
             '-ls': self.list_bucket
         }
 
+    def _progress_bar(self, cur, total):
+        """
+        创建一个进度条并启动
+
+        Create a progress bar and start
+
+        :param cur: 当前完成量
+        :param total: 总任务量
+        :return: None
+        """
+        if not self.progress:
+            from ..TuiTools.Bar import DataTransformBar
+            self.progress = DataTransformBar(True if total else False)
+            self.trans_id = self.progress.add_task('Transform', total=total if total else -1,
+                                                   filename=self._progress_file_name)
+            self.progress.start()
+            self.progress.start_task(self.trans_id)
+        self.progress.update(self.trans_id, completed=cur)
+
     def upload(self, filePath: str, bucket: str = None):
         """
         上传文件（支持断点续传）
@@ -55,10 +75,17 @@ class AliyunOSS:
         :param bucket: 桶名称，缺省使用self.df_bucket
         :return: None
         """
+        import os
+        from .. import qs_default_console, qs_info_string
+        from ..SystemTools import get_core_num
         bucket = bucket if bucket else self.df_bucket
         bucket = oss2.Bucket(self.auth, self.bucket_url, bucket)
         filePath = filePath.strip()
-        oss2.resumable_upload(bucket, filePath.replace(dir_char, '/'), filePath, num_threads=4)
+        self._progress_file_name = os.path.basename(filePath)
+        oss2.resumable_upload(bucket, filePath.replace(dir_char, '/'), filePath, num_threads=get_core_num() * 4,
+                              progress_callback=self._progress_bar)
+        self.progress.stop()
+        qs_default_console.print(qs_info_string, 'Transform Completed!' if user_lang != 'zh' else '传输完成!')
 
     def download(self, filename: str, bucket: str = None):
         """
@@ -70,9 +97,16 @@ class AliyunOSS:
         :param bucket: 桶名称，缺省使用self.df_bucket
         :return: None
         """
+        import os
+        from .. import qs_default_console, qs_info_string
+        from ..SystemTools import get_core_num
         bucket = bucket if bucket else self.df_bucket
         bucket = oss2.Bucket(self.auth, self.bucket_url, bucket)
-        oss2.resumable_download(bucket, filename, filename, num_threads=4)
+        self._progress_file_name = os.path.basename(filename)
+        oss2.resumable_download(bucket, filename, filename, num_threads=get_core_num() * 4,
+                                progress_callback=self._progress_bar)
+        self.progress.stop()
+        qs_default_console.print(qs_info_string, 'Transform Completed!' if user_lang != 'zh' else '传输完成!')
 
     def remove(self, filePath: str, bucket: str = None):
         """
@@ -99,17 +133,12 @@ class AliyunOSS:
         """
         from .. import qs_default_console, qs_info_string
         from ..NetTools.NormalDL import size_format
-        from rich.table import Table, Column
+        from ..TuiTools.Table import qs_default_table
         from rich.text import Text
-        from rich.box import SIMPLE
+
         bucket = bucket if bucket else self.df_bucket
         ls = oss2.Bucket(self.auth, self.bucket_url, bucket)
-        tb = Table(
-            *([Column('File', justify="center"), Column('Size', justify="center")]
-              if user_lang != 'zh' else
-              [Column('文件', justify="center"), Column('体积', justify="center")])
-            , show_edge=False, row_styles=['none', 'dim'], box=SIMPLE, title='[bold underline]Aliyun OSS'
-        )
+        tb = qs_default_table(['File', 'Size'] if user_lang != 'zh' else ['文件', '体积'], title='Aliyun OSS')
         prefix = dict()
         for obj in oss2.ObjectIterator(ls):
             if '/' in obj.key:
